@@ -61,7 +61,7 @@ def simple_filter(
             # Searching data fields
             search_value = d[attr]
         elif (property_field and property_field in d and
-                type(d[property_field]) is dict):
+                isinstance(d[property_field], dict)):
             # Searching a properties field - do this separately because
             # we don't want to fail over to checking the fields if a
             # property name is given.
