@@ -15,15 +15,12 @@
 
 """Identity v3 Role action implementations"""
 
-import logging
 import six
 import sys
 
-from cliff import command
-from cliff import lister
-from cliff import show
 from keystoneauth1 import exceptions as ks_exc
 
+from openstackclient.common import command
 from openstackclient.common import utils
 from openstackclient.i18n import _  # noqa
 from openstackclient.identity import common
@@ -110,8 +107,6 @@ def _process_identity_and_resource_options(parsed_args,
 class AddRole(command.Command):
     """Adds a role to a user or group on a domain or project"""
 
-    log = logging.getLogger(__name__ + '.AddRole')
-
     def get_parser(self, prog_name):
         parser = super(AddRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -122,14 +117,12 @@ class AddRole(command.Command):
         _add_identity_and_resource_options_to_parser(parser)
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
         if (not parsed_args.user and not parsed_args.domain
                 and not parsed_args.group and not parsed_args.project):
             return
-
         role = utils.find_resource(
             identity_client.roles,
             parsed_args.role,
@@ -144,14 +137,11 @@ class AddRole(command.Command):
             return
 
         identity_client.roles.grant(role.id, **kwargs)
-        return
 
 
-class CreateRole(show.ShowOne):
+class CreateRole(command.ShowOne):
     """Create new role"""
 
-    log = logging.getLogger(__name__ + '.CreateRole')
-
     def get_parser(self, prog_name):
         parser = super(CreateRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -166,7 +156,6 @@ class CreateRole(show.ShowOne):
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
@@ -187,8 +176,6 @@ class CreateRole(show.ShowOne):
 class DeleteRole(command.Command):
     """Delete role(s)"""
 
-    log = logging.getLogger(__name__ + '.DeleteRole')
-
     def get_parser(self, prog_name):
         parser = super(DeleteRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -199,7 +186,6 @@ class DeleteRole(command.Command):
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
@@ -209,21 +195,17 @@ class DeleteRole(command.Command):
                 role,
             )
             identity_client.roles.delete(role_obj.id)
-        return
 
 
-class ListRole(lister.Lister):
+class ListRole(command.Lister):
     """List roles"""
 
-    log = logging.getLogger(__name__ + '.ListRole')
-
     def get_parser(self, prog_name):
         parser = super(ListRole, self).get_parser(prog_name)
         _add_identity_and_resource_options_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
 
         if parsed_args.user:
@@ -318,8 +300,6 @@ class ListRole(lister.Lister):
 class RemoveRole(command.Command):
     """Remove role from domain/project : user/group"""
 
-    log = logging.getLogger(__name__ + '.RemoveRole')
-
     def get_parser(self, prog_name):
         parser = super(RemoveRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -330,14 +310,15 @@ class RemoveRole(command.Command):
         _add_identity_and_resource_options_to_parser(parser)
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
         if (not parsed_args.user and not parsed_args.domain
                 and not parsed_args.group and not parsed_args.project):
+            sys.stderr.write("Incorrect set of arguments "
+                             "provided. See openstack --help for more "
+                             "details\n")
             return
-
         role = utils.find_resource(
             identity_client.roles,
             parsed_args.role,
@@ -349,16 +330,12 @@ class RemoveRole(command.Command):
             sys.stderr.write("Role not removed, incorrect set of arguments \
             provided. See openstack --help for more details\n")
             return
-
         identity_client.roles.revoke(role.id, **kwargs)
-        return
 
 
 class SetRole(command.Command):
     """Set role properties"""
 
-    log = logging.getLogger(__name__ + '.SetRole')
-
     def get_parser(self, prog_name):
         parser = super(SetRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -373,27 +350,25 @@ class SetRole(command.Command):
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
         if not parsed_args.name:
+            sys.stderr.write("Incorrect set of arguments "
+                             "provided. See openstack --help for more "
+                             "details\n")
             return
-
         role = utils.find_resource(
             identity_client.roles,
             parsed_args.role,
         )
 
         identity_client.roles.update(role.id, name=parsed_args.name)
-        return
 
 
-class ShowRole(show.ShowOne):
+class ShowRole(command.ShowOne):
     """Display role details"""
 
-    log = logging.getLogger(__name__ + '.ShowRole')
-
     def get_parser(self, prog_name):
         parser = super(ShowRole, self).get_parser(prog_name)
         parser.add_argument(
@@ -403,7 +378,6 @@ class ShowRole(show.ShowOne):
         )
         return parser
 
-    @utils.log_method(log)
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
