@@ -49,6 +49,29 @@ class TestVolume(volume_fakes.TestVolumev1):
 
 class TestVolumeCreate(TestVolume):
 
+    columns = (
+        'attach_status',
+        'availability_zone',
+        'display_description',
+        'display_name',
+        'id',
+        'properties',
+        'size',
+        'status',
+        'type',
+    )
+    datalist = (
+        'detached',
+        volume_fakes.volume_zone,
+        volume_fakes.volume_description,
+        volume_fakes.volume_name,
+        volume_fakes.volume_id,
+        volume_fakes.volume_metadata_str,
+        volume_fakes.volume_size,
+        volume_fakes.volume_status,
+        volume_fakes.volume_type,
+    )
+
     def setUp(self):
         super(TestVolumeCreate, self).setUp()
 
@@ -72,7 +95,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -93,31 +118,8 @@ class TestVolumeCreate(TestVolume):
             None,
             None,
         )
-
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_options(self):
         arglist = [
@@ -136,7 +138,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -158,30 +162,8 @@ class TestVolumeCreate(TestVolume):
             None,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_user_project_id(self):
         # Return a project
@@ -211,7 +193,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -233,30 +217,8 @@ class TestVolumeCreate(TestVolume):
             None,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_user_project_name(self):
         # Return a project
@@ -286,7 +248,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -308,30 +272,8 @@ class TestVolumeCreate(TestVolume):
             None,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_properties(self):
         arglist = [
@@ -347,7 +289,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -369,30 +313,8 @@ class TestVolumeCreate(TestVolume):
             None,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_image_id(self):
         self.images_mock.get.return_value = fakes.FakeResource(
@@ -413,7 +335,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -435,30 +359,8 @@ class TestVolumeCreate(TestVolume):
             volume_fakes.image_id,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
     def test_volume_create_image_name(self):
         self.images_mock.get.return_value = fakes.FakeResource(
@@ -479,7 +381,9 @@ class TestVolumeCreate(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
 
         # VolumeManager.create(size, snapshot_id=, source_volid=,
@@ -501,34 +405,29 @@ class TestVolumeCreate(TestVolume):
             volume_fakes.image_id,
         )
 
-        collist = (
-            'attach_status',
-            'availability_zone',
-            'display_description',
-            'display_name',
-            'id',
-            'properties',
-            'size',
-            'status',
-            'type',
-        )
-        self.assertEqual(collist, columns)
-        datalist = (
-            'detached',
-            volume_fakes.volume_zone,
-            volume_fakes.volume_description,
-            volume_fakes.volume_name,
-            volume_fakes.volume_id,
-            volume_fakes.volume_metadata_str,
-            volume_fakes.volume_size,
-            volume_fakes.volume_status,
-            volume_fakes.volume_type,
-        )
-        self.assertEqual(datalist, data)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, data)
 
 
 class TestVolumeList(TestVolume):
 
+    columns = (
+        'ID',
+        'Display Name',
+        'Status',
+        'Size',
+        'Attached to',
+    )
+    datalist = (
+        (
+            volume_fakes.volume_id,
+            volume_fakes.volume_name,
+            volume_fakes.volume_status,
+            volume_fakes.volume_size,
+            '',
+        ),
+    )
+
     def setUp(self):
         super(TestVolumeList, self).setUp()
 
@@ -555,23 +454,8 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        collist = (
-            'ID',
-            'Display Name',
-            'Status',
-            'Size',
-            'Attached to',
-        )
-        self.assertEqual(collist, columns)
-
-        datalist = ((
-            volume_fakes.volume_id,
-            volume_fakes.volume_name,
-            volume_fakes.volume_status,
-            volume_fakes.volume_size,
-            '',
-        ), )
-        self.assertEqual(datalist, tuple(data))
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.datalist, tuple(data))
 
     def test_volume_list_name(self):
         arglist = [
@@ -586,24 +470,8 @@ class TestVolumeList(TestVolume):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-
-        collist = (
-            'ID',
-            'Display Name',
-            'Status',
-            'Size',
-            'Attached to',
-        )
-        self.assertEqual(collist, tuple(columns))
-
-        datalist = ((
-            volume_fakes.volume_id,
-            volume_fakes.volume_name,
-            volume_fakes.volume_status,
-            volume_fakes.volume_size,
-            '',
-        ), )
-        self.assertEqual(datalist, tuple(data))
+        self.assertEqual(self.columns, tuple(columns))
+        self.assertEqual(self.datalist, tuple(data))
 
     def test_volume_list_status(self):
         arglist = [
@@ -618,24 +486,8 @@ class TestVolumeList(TestVolume):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-
-        collist = (
-            'ID',
-            'Display Name',
-            'Status',
-            'Size',
-            'Attached to',
-        )
-        self.assertEqual(collist, tuple(columns))
-
-        datalist = ((
-            volume_fakes.volume_id,
-            volume_fakes.volume_name,
-            volume_fakes.volume_status,
-            volume_fakes.volume_size,
-            '',
-        ), )
-        self.assertEqual(datalist, tuple(data))
+        self.assertEqual(self.columns, tuple(columns))
+        self.assertEqual(self.datalist, tuple(data))
 
     def test_volume_list_all_projects(self):
         arglist = [
@@ -650,24 +502,8 @@ class TestVolumeList(TestVolume):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-
-        collist = (
-            'ID',
-            'Display Name',
-            'Status',
-            'Size',
-            'Attached to',
-        )
-        self.assertEqual(collist, columns)
-
-        datalist = ((
-            volume_fakes.volume_id,
-            volume_fakes.volume_name,
-            volume_fakes.volume_status,
-            volume_fakes.volume_size,
-            '',
-        ), )
-        self.assertEqual(datalist, tuple(data))
+        self.assertEqual(self.columns, tuple(columns))
+        self.assertEqual(self.datalist, tuple(data))
 
     def test_volume_list_long(self):
         arglist = [
@@ -760,7 +596,6 @@ class TestVolumeSet(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
         self.cmd.take_action(parsed_args)
 
         # Set expected values
@@ -786,7 +621,6 @@ class TestVolumeSet(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
         self.cmd.take_action(parsed_args)
 
         # Set expected values
@@ -812,7 +646,6 @@ class TestVolumeSet(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
         self.cmd.take_action(parsed_args)
 
         # Set expected values
@@ -878,7 +711,6 @@ class TestVolumeSet(TestVolume):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # DisplayCommandBase.take_action() returns two tuples
         self.cmd.take_action(parsed_args)
 
         # Set expected values
