@@ -16,22 +16,16 @@
 """Volume v1 Snapshot action implementations"""
 
 import copy
-import logging
 import six
 
-from cliff import command
-from cliff import lister
-from cliff import show
-
+from openstackclient.common import command
 from openstackclient.common import parseractions
 from openstackclient.common import utils
 
 
-class CreateSnapshot(show.ShowOne):
+class CreateSnapshot(command.ShowOne):
     """Create new snapshot"""
 
-    log = logging.getLogger(__name__ + '.CreateSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(CreateSnapshot, self).get_parser(prog_name)
         parser.add_argument(
@@ -60,7 +54,6 @@ class CreateSnapshot(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         volume_client = self.app.client_manager.volume
         volume_id = utils.find_resource(volume_client.volumes,
                                         parsed_args.volume).id
@@ -81,8 +74,6 @@ class CreateSnapshot(show.ShowOne):
 class DeleteSnapshot(command.Command):
     """Delete snapshot(s)"""
 
-    log = logging.getLogger(__name__ + '.DeleteSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(DeleteSnapshot, self).get_parser(prog_name)
         parser.add_argument(
@@ -94,22 +85,24 @@ class DeleteSnapshot(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         volume_client = self.app.client_manager.volume
         for snapshot in parsed_args.snapshots:
             snapshot_id = utils.find_resource(volume_client.volume_snapshots,
                                               snapshot).id
             volume_client.volume_snapshots.delete(snapshot_id)
-        return
 
 
-class ListSnapshot(lister.Lister):
+class ListSnapshot(command.Lister):
     """List snapshots"""
 
-    log = logging.getLogger(__name__ + '.ListSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(ListSnapshot, self).get_parser(prog_name)
+        parser.add_argument(
+            '--all-projects',
+            action='store_true',
+            default=False,
+            help='Include all projects (admin only)',
+        )
         parser.add_argument(
             '--long',
             action='store_true',
@@ -119,7 +112,6 @@ class ListSnapshot(lister.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
 
         def _format_volume_id(volume_id):
             """Return a volume name if available
@@ -157,7 +149,12 @@ class ListSnapshot(lister.Lister):
             # Just forget it if there's any trouble
             pass
 
-        data = self.app.client_manager.volume.volume_snapshots.list()
+        search_opts = {
+            'all_tenants': parsed_args.all_projects,
+        }
+
+        data = self.app.client_manager.volume.volume_snapshots.list(
+            search_opts=search_opts)
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
@@ -169,8 +166,6 @@ class ListSnapshot(lister.Lister):
 class SetSnapshot(command.Command):
     """Set snapshot properties"""
 
-    log = logging.getLogger(__name__ + '.SetSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(SetSnapshot, self).get_parser(prog_name)
         parser.add_argument(
@@ -195,7 +190,6 @@ class SetSnapshot(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         volume_client = self.app.client_manager.volume
         snapshot = utils.find_resource(volume_client.volume_snapshots,
                                        parsed_args.snapshot)
@@ -215,14 +209,11 @@ class SetSnapshot(command.Command):
             return
 
         snapshot.update(**kwargs)
-        return
 
 
-class ShowSnapshot(show.ShowOne):
+class ShowSnapshot(command.ShowOne):
     """Display snapshot details"""
 
-    log = logging.getLogger(__name__ + '.ShowSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(ShowSnapshot, self).get_parser(prog_name)
         parser.add_argument(
@@ -232,7 +223,6 @@ class ShowSnapshot(show.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         volume_client = self.app.client_manager.volume
         snapshot = utils.find_resource(volume_client.volume_snapshots,
                                        parsed_args.snapshot)
@@ -247,8 +237,6 @@ class ShowSnapshot(show.ShowOne):
 class UnsetSnapshot(command.Command):
     """Unset snapshot properties"""
 
-    log = logging.getLogger(__name__ + '.UnsetSnapshot')
-
     def get_parser(self, prog_name):
         parser = super(UnsetSnapshot, self).get_parser(prog_name)
         parser.add_argument(
@@ -268,7 +256,6 @@ class UnsetSnapshot(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         volume_client = self.app.client_manager.volume
         snapshot = utils.find_resource(
             volume_client.volume_snapshots, parsed_args.snapshot)
@@ -280,4 +267,3 @@ class UnsetSnapshot(command.Command):
             )
         else:
             self.app.log.error("No changes requested\n")
-        return
